@@ -1,13 +1,13 @@
 import sys
 
-from html_to_markdown.cli import main
+from html_to_markdown.cli_proxy import main
 
 
 def cli() -> None:
     try:
         result = main(sys.argv[1:])
-        print(result)  # noqa: T201
-    except ValueError as e:
+        print(result, end="")  # noqa: T201
+    except (ValueError, FileNotFoundError) as e:
         print(str(e), file=sys.stderr)  # noqa: T201
         sys.exit(1)
 
